@@ -1,11 +1,7 @@
 import openai
 import json
 
-f = open("config.json")
-data = json.load(f)
-API_KEY = data["API_KEY"]
-
-openai.api_key = API_KEY
+openai.api_key = "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"
 
 model = 'text-davinci-003'
 
